@@ -1158,8 +1158,8 @@ return(TRUE)
 	selection <- gtkTreeViewGetSelection(treeview)
 	iter <- gtkTreeSelectionGetSelected(selection)$iter	
 
-	vis <- model$get(iter, .womDefinedModelsTreeCols("visible"))[[1]]
-	return(list(iter=iter,visible=vis))
+	#vis <- model$get(iter, .womDefinedModelsTreeCols("visible"))[[1]]
+	return(list(iter=iter,visible=NULL))
 }
 
 
